use 5.008001;
use strict;
use warnings;
use lib 't/lib';

use Test::More 0.96;

use UNIVERSAL::new;

use LoadTest;

done_testing;
#
# This file is part of UNIVERSAL-new
#
# This software is Copyright (c) 2013 by David Golden.
#
# This is free software, licensed under:
#
#   The Apache License, Version 2.0, January 2004
#
# vim: ts=4 sts=4 sw=4 et:
